# Note: This spec file is largely shared with the public virtio-win drivers
# shipped on fedoraproject.org. If you make any changes to this file that
# affect the RPM content, please submit a patch them to the upstream spec
# file hosted at: https://github.com/crobinso/virtio-win-pkg-scripts

%global virtio_win_prewhql_build virtio-win-prewhql-0.1-126
%global qemu_ga_win_build qemu-ga-win-7.3.2-1
%global qxl_build qxl-win-unsigned-0.1-24

Summary: VirtIO para-virtualized drivers for Windows(R)
Name: virtio-win
Version: 1.8.0
Release: 1%{?dist}
Group: Applications/System
URL: http://www.redhat.com/
BuildArch: noarch

%if 0%{?rhel}
# RHEL RPM ships WHQL signed drivers, which are under a proprietary license
# qemu-ga builds are GPLv2
License: Red Hat Proprietary and GPLv2
%else
# virtio-win: https://github.com/YanVugenfirer/kvm-guest-drivers-windows/blob/master/LICENSE
# qxl: http://cgit.freedesktop.org/spice/win32/qxl/tree/xddm/COPYING
# qemu-ga: http://git.qemu.org/?p=qemu.git;a=blob;f=COPYING
License: GPLv2
%endif

# Already built files
Source1: %{name}-%{version}-bin-for-rpm.tar.gz
Source2: %{qemu_ga_win_build}-installers.zip

# Source files shipped in the srpm
Source3: %{virtio_win_prewhql_build}-sources.zip
Source4: %{qxl_build}-sources.zip
Source5: %{qemu_ga_win_build}-sources.zip

BuildRequires: /usr/bin/mkisofs


%description
VirtIO para-virtualized Windows(R) drivers for 32-bit and 64-bit
Windows(R) guests.


%prep
%setup -q -T -b 1 -n %{name}-%{version}
%setup -q -T -a 2 -n %{name}-%{version} -D


%build
%{__mv} %{qemu_ga_win_build} guest-agent

# Generate .iso
/usr/bin/mkisofs -m vfddrivers -o %{name}-%{version}.iso -r -J \
  -input-charset iso8859-1 -V "%{name}-%{version}" .


%install
%{__install} -d -m0755 %{buildroot}%{_datadir}/%{name}

# Install .iso, create non-versioned symlink
%{__install} -p -m0644 %{name}-%{version}.iso %{buildroot}%{_datadir}/%{name}
%{__ln_s} %{name}-%{version}.iso %{buildroot}%{_datadir}/%{name}/%{name}.iso

# Install .vfd files, create non-versioned symlinks
%{__install} -p -m0644 %{name}-%{version}_x86.vfd  %{buildroot}%{_datadir}/%{name}
%{__ln_s} %{name}-%{version}_x86.vfd %{buildroot}%{_datadir}/%{name}/%{name}_x86.vfd
%{__install} -p -m0644 %{name}-%{version}_amd64.vfd  %{buildroot}%{_datadir}/%{name}
%{__ln_s} %{name}-%{version}_amd64.vfd %{buildroot}%{_datadir}/%{name}/%{name}_amd64.vfd

%{__cp} -a vfddrivers %{buildroot}/%{_datadir}/%{name}/drivers
%{__cp} -a guest-agent %{buildroot}/%{_datadir}/%{name}


%files
%doc virtio-win_license.txt
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/%{name}-%{version}.iso
%{_datadir}/%{name}/%{name}.iso
%{_datadir}/%{name}/*.vfd
%{_datadir}/%{name}/drivers
%{_datadir}/%{name}/guest-agent


%changelog
* Mon Oct 31 2016 Yash Mankad <ymankad@redhat.com> - 1.8.0-1

- The virtio-win-1.8.0-1 release contains:
  - support for Windows 2016
  - Bugfixes and improvements (see below for bugzilla list)

- The drivers contained in this release are:
  - pvpanic build 121
  - Balloon build 125
  - viorng  build 125
  - viostor build 126
  - NetKVM  build 126
  - vioser  build 126
  - vioscsi build 124

- Also included in this release are:
  - qemu guest agent 7.3.2-1
  - qxl 0.1-24

This release addresses the following BZs:
- Resolves: bz#1384587
  (Backport virtio-win from RHEL-7.3 to RHEL-6.9)
- Resolves: bz#1290305
  (Win7 64bit guest got BSOD with error 0x0000000A when reboot several times)
- Resolves: bz#1304973
  (virtio-win 1.7.4 doesn't provide windows 10 drivers within vfd [rhel-6.9])
- Resolves: bz#1303906
  (RFE: [qemu-ga] provide command for setting administrator account password (Windows guest) [rhel-6.9])
- Solves: bz#950611
  ([NetKVM] Pass WHQL tests with RSC feature enabled )
- Solves: bz#954183
  ([NetKVM] Static driver verifier fails with NetKVM )
- Solves: bz#1013336
  ([virtio-win][netkvm] BSoD occurs when running NDISTest6.5 -[2 Machine] - MPE_Ethernet job on windows 2012 (Win10))
- Solves: bz#1122364
  ([virtio-win][vioser][rhel6]win2k8r2 guest bsod(7e) when do continuous hotplug/unplug during virtio serial in use with driver verifier enabled)
- Solves: bz#1157987
  (Windows hangs at startup if virtio-scsi device is configured with vectors=1, 2, and 3)
- Solves: bz#1161453
  ([whql][vioscsi]Job named by SCSI Compliance Test (LOGO) failed on win2k8-R2 and win8-64 guest)
- Solves: bz#1190960
  ([whql][netkvm][mq]job failed due to "Received some net buffer lists out of order" w/ 4 queues)
- Solves: bz#1208465
  (Windows guest boots up slowly with multiple virtual NIC devices (I attached 232 with mutifunction=on))
- Solves: bz#1210166
  ([vioscsi] Add multiqueue support to Windows virtio-scsi driver.)
- Solves: bz#1214177
  ([virtio-win] [NetKVM] Compilation errors with Visual Studio 2015 while trying to compile NetKVM)
- Solves: bz#1214568
  ([RFE][virtio-win] Add WMI facility to check the virito-scsi mq enabled)
- Solves: bz#1219841
  ([RFE] vioscsi.sys should support MS Cluster Services)
- Solves: bz#1223426
  ([NetKVM] Performance degradation with multi-queue)
- Solves: bz#1234741
  ([virtio-win][vioscsi]win2012 guest bsod(c9) when whql test DPWLK-HotAdd(1104) job)
- Solves: bz#1234751
  ([virtio-win][vioscsi]win2012R2 guest bsod(d1) when whql test DPWLK-HotAdd(1104) job)
- Solves: bz#1235108
  ([virtio-win][vioscsi]VIOSCSI driver is not signed by redhat certification on win200832/64 platform)
- Solves: bz#1237024
  ([virtio-win][netkvm]ipv6 uploading speed is quite slow when set "TCP/UDP checksum offload(IPv6)" to "Rx & Tx Enabled")
- Solves: bz#1241986
  (win7 64bit BSOD when booting it on RHEL7.2 host)
- Solves: bz#1243229
  ([virtio-win][scsi][windows 10]win10 and win2016 guests bsod with D1 when run job "Bus Reset Test")
- Solves: bz#1245957
  ([WHQL][viostor][data-plane]it could not generate dump file on WIN2008-32/64 via WLK while running Crash Dump job)
- Solves: bz#1246993
  ([virtio-win][svvp][ws2016] job "Signed Driver Check (CheckLogo)" failed during ws2016 svvp test)
- Solves: bz#1247006
  ([virtio-win][svvp][ws2016] job "Profile Interrupt Test" failed during ws2016 svvp test)
- Solves: bz#1248873
  ([whql][netkvm]Job named NDISTest6.5-InvalidPackets failed with HCK on win8-32/win8-64(build 106))
- Solves: bz#1248977
  ([virtio-win][vioscsi] Cannot install vioscsi driver on win7-32&win2008-32)
- Solves: bz#1249867
  ([WHQL][vioscsi]Job hangs and it cannot continure on windows2008 guest via WLK)
- Solves: bz#1250854
  ([WHQL][vioscsi]The job named crash dump failed on windows 2008 -32/64 platform)
- Solves: bz#1256583
  (Win10 guest can't get ip address from dhcpserver when add mrg_rxbuf=off for virtio-net-pci)
- Solves: bz#1266340
  ([whql][netkvm]NDISTest6.5 Manual test failed and generate dump file on windows 2008 guest)
- Solves: bz#1270149
  ([virtio-win][netkvm] Check guest network link status of virtio nic with status=on failed (build 110))
- Solves: bz#1289406
  ([virtio-win][vioser] Cannot install vioser driver successfully)
- Solves: bz#1292788
  ([virtio-win][viostor] Cannot install viostor driver on win7-64&win2008-64&win2008R2)
- Solves: bz#1293042
  ([virtio-win][vioser] Extra '-' (dash) in serial driver name)
- Solves: bz#1293249
  ([virtio-win][vioser] IOCTL_GET_INFORMATION does not return required buffer size)
- Solves: bz#1296092
  ([virtio-win][balloon] balloon driver can not be installed automately via pnputil)
- Solves: bz#1303511
  (update copyright of license.txt file in virtio-win to 2016)
- Solves: bz#1303809
  (provide QEMU guest agent command for setting root/administrator account password - window guests)
- Solves: bz#1303988
  ([virtio-win] [virtio-1] [RFE] Add Virtio-1.0 support for NetKVM)
- Solves: bz#1304041
  ([virtio-win] [virtio-1] [RFE] Add Virtio-1.0 support for vioserial)
- Solves: bz#1304044
  ([virtio-win] [virtio-1] [RFE] Add Virtio-1.0 support for vioscsi)
- Solves: bz#1304049
  ([virtio-win] [virtio-1] [RFE] Add Virtio-1.0 support for viostor)
- Solves: bz#1313243
  ([virtio-win][netkvm][rhel6]win2008-32 guest bsod with HARDWARE_INTERRUP_STORM(f2) when running netper
f for longevity test)
- Solves: bz#1313887
  ([RFE] provide QEMU guest agent command for setting root account password (Windows guest) [rhel-7.3])
- Solves: bz#1315984
  ([virtio-win] [virtio-1] [RFE] Add Virtio-1.0 support for baloon)
- Solves: bz#1315985
  ([virtio-win] [virtio-1] [RFE] Add Virtio-1.0 support for rng)
- Solves: bz#1321774
  ([virtio-win][vioscsi]fio jobs keep printing "0% done" in win2012r2 guest)
- Solves: bz#1325078
  (Add TargetOSVersion to driver inf files)
- Solves: bz#1328275
  (virtio-win doesn't provide windows 10 drivers within vfd [rhel-7.3])
- Solves: bz#1334736
  (On the LAN network, as long as the VMs receive the Network message, and will always blue screen.)
- Solves: bz#1336368
  ([virtio-win][viostor][virtio1.0]Cannot enlarge/shrink disk with virtio1.0 device)
- Solves: bz#1339175
  ([NetKVM] Turn on RSC feature in NetKVM driver)
- Solves: bz#1340571
  (Add Windows 2k16 drivers to virtio-win)
- Solves: bz#1352432
  ([virtio-win][vioscsi]Win2012-64&R2 guest occurred bsod(d1) when whql test DPWLK- Hot-Replace - Device Test - Verify driver support for D3 power state)
- Solves: bz#1352517
  ([virtio-win][balloon][whql]windows guest BSOD when run several WHQL jobs)
- Solves: bz#1352809
  ([virtio-win][viorng]wrong dervier version for virtio-win-prewhql-121)
- Solves: bz#1356363
  ([virtio-win][viorng] cannot install viorng driver on win2008-32/64 (build 122) )
- Solves: bz#1358125
  (Virtio 1.0 driver didn't work on win10 with q35 machine type)
- Solves: bz#1359072
  ([virtio-win][netkvm][whql]many whql jobs occurred BSOD(DRIVER_VERIFIER_DETECTED_VIOLATION (c4)) on build 122)
- Solves: bz#1361501
  ([virtio-win][balloon] report "VCRUNTIME120.dll is missing from your computer"error when using blnsvr.exe)

* Wed Jun 22 2016 Yash Mankad <ymankad@redhat.com> - 1.7.5-1

- The virtio-win-1.7.5-1 release contains:
  - Windows 10 drivers within vfd files

- Resolves: bz#1304973
  (virtio-win 1.7.4 doesn't provide windows 10 drivers within vfd [rhel6.9] )

* Thu Nov 19 2015 Jeff E. Nelson <jen@redhat.com> - 1.7.5-0

- The virtio-win-1.7.5-0 release contains:
  - support for Windows 10
  - Bugfixes and improvements (see below for bugzilla list)

- The drivers contained in this release are:
  - Balloon build 105
  - viorng  build 105
  - viostor build 106
  - NetKVM  build 105 (Windows Server 2008) and build 110 (all others)
  - vioser  build 108
  - vioscsi build 102

- Also included in this release are:
  - qemu guest agent 7.0-10
  - qxl 0.1-24

- Resolves: bz#1275050
  (VirtIO-Win must be repackaged for RHEL 6 with Windows 10 drivers [rhel6.8])

This release also addresses the following BZs:
- bz#1010887
  ([virtio-win][balloon] Guest display did not show properly after hibernate guest(s4)& resume after enlarging memory during runtime)
- bz#1017817
  (copying of 10+ MB plaintext from guest through spice clipboard to client results in: vio_serial write completion error 554)
- bz#1037949
  ([virtio-win][viostor]guest bsod(9F) when do s4 while guest running iozone)
- bz#1054640
  ([virtio-win][netkvm]windows 8.1 x86 BSOD on DRIVER_POWER_STATE_FAILURE (9f))
- bz#1058115
  ([whql][netkvm]win2k8-32 BSOD with code 9F when run WLK job "Ethernet - NDISTest 6.5 (MPE)")
- bz#1058121
  ([whql][netkvm]win2k8-32 BSOD with 7E code when run WLK job "Ethernet - NDISTest 6.5 (MPE)")
- bz#1058225
  ([WHQL][netkvm]Job named PM_PowerStateTransition failed because error pop up while test app's running on win8/win8.1)
- bz#1067249
  ([virtio-win][balloon]Balloon device can not be removed after blnsrv service installed)
- bz#1085702
  ([WHQL][netkvm][macvtap][1 machine]OffloadRsc failed on win2012 and win8-64 guest)
- bz#1096505
  ([NetKVM] Implement multiqueue support in Windows guest driver)
- bz#1098876
  ([virtio-win][netkvm]netkvm driver can not be installed on win8-64 guests)
- bz#1100308
  ([NetKVM] Race condition in handling device stop)
- bz#1103100
  ([virtio-win][netkvm]netkvm driver can not be load in win2008 guest)
- bz#1106400
  ([whql][netkvm]NDISTest 6.5 - [2 Machine] - OffloadLSO failed)
- bz#1109027
  ([virtio-win][netkvm]Name field is empty when using netsh command)
- bz#1110129
  ([virtio-win][scsi]scsi driver can not be installed automately via pnputil)
- bz#1111051
  ([virtio-win][netkvm]win7-32 guest bsod(8e) while performing long (several hours) netperf transfer with mq=on)
- bz#1112712
  ([virtio-win][netkvm]win8.1 32bit BSOD when loading virtio-win-prewhql-0.1 driver & indirect_desc=off option of virtio-net-pci)
- bz#1119966
  ([whql][netkvm][RHEL6]guests bsod (0xd1) when running job "NDISTest 6.5 - [1 Machine] - StandardizedKeywords")
- bz#1121338
  ([WHQL][netkvm]NDISTest 6.5 - 2 Machine - OffloadChecksum failed via bridge on hck)
- bz#1123288
  ([virtio-win][netkvm]BOSD occurs during guest reboot after disable nic when netserver running)
- bz#1125796
  ("Guest moved used index from 10122 to 10253" when reboot win2012R2 guest with 129 virtio-scsi target)
- bz#1126378
  ([virtio-win][vioscsi][rhel6]win2012 guest bsod(d1) when shutdown guest with multi virtio-scsi devices on the same scsi controller)
- bz#1136023
  ([NetKVM] Google patches broke debug compilation of NetKVM driver)
- bz#1136602
  ([whql][netkvm]Guest (64 bits Operating System) got BSOD (DRIVER_VERIFIER_DETECTED_VIOLATION) while run some jobs)
- bz#1136606
  ([whql][netkvm]guests bsod(7E) when running job "NDISTest 6.0 - [1 Machine] - 1c_FaultHandling")
- bz#1140447
  ([virtio-win][viorng]should use uniformed name for WDFCoinstallerXXX.dll)
- bz#1142737
  ([virtio-win][netkvm]interface status is '2', but expect status is '7' after set_link NIC off)
- bz#1147202
  ([virtio-win][WHQL][netkvm]Job named by InvalidPackets induce win81-32/64 to hang up.)
- bz#1147203
  ([virtio-win][whql][netkvm]win2k8-64 bsod(7e) when run job "Ethernet - NDISTest 6.0")
- bz#1147239
  (NetKVM with 2012R2 fails the HCK tests)
- bz#1154419
  (NetKVM fails HCK test for 2008R2, single CPU)
- bz#1154420
  (ParaNdis6_SendNetBufferList should dispatch each net buffer to a separate queue)
- bz#1154435
  ([NetKVM] Incorrect message id assignment and queue allocation)
- bz#1155891
  ([whql][netkvm]Job MPE failed while job was running on win2008R2 because of bsod (0A) on build 93 - 4 vcpus)
- bz#1155910
  ([whql][netkvm]Job MPE failed while job was running on win2008R2 because of bsod (D1) on build 93 - 1 vcpus)
- bz#1156259
  (Win7-64 guest BSOD(0x000000A0) when doing s4)
- bz#1157241
  ([NetKVM] Uninitialized reserved field in procNumber structure)
- bz#1159732
  ([virtio-win][vioscsi]guest shutdown instead of S3/S4 while doing S3/S4 in guest)
- bz#1159754
  ([virtio-win][netkvm]Nic device doesn't work when guest is running in IRQ mode)
- bz#1167539
  (win8.1.32 guest BSOD with error ' MEMORY_MANAGEMENT)
- bz#1167614
  (win8.1.32 guest BSOD with error 'DRIVER_IRQL_NOT_LESS_OR_EQUAL' (netkvm.sys))
- bz#1168119
  ([virtio-win][netkvm]win8.1.64 guest BSOD with error 'DRIVER_IRQL_NOT_LESS_OR_EQUAL' (netkvm.sys) after first reboot during os installation on AMD host)
- bz#1168483
  ([virtio-win][netkvm]guest lost ip when change MTU between 500 and 575 via device manage)
- bz#1168784
  ([virtio-win]win2012r2 guest shows black screen with error code "0x0000005c" after migration and reboot)
- bz#1169673
  ([virtio-win][netkvm]qemu quit with "qemu-kvm: Guest moved used index from 0 to 257" when set MaxRxBuffers to 512/1024 in guest)
- bz#1169718
  (CVE-2015-3215 [NetKVM] Malformed packet can cause BSOD [rhel-7.2])
- bz#1170106
  (RFE: [virtio-win][qxl-win] Add windows 2008R2 QXL to the .vfd)
- bz#1172920
  ([virtio-win][vioser]winxp guest bsod with D1 code when shutdown guest after hotunplug/hotplug serial port and serial pci)
- bz#1173323
  (iperf stalls the NetKVM driver)
- bz#1177063
  ([virtio-win][balloon]guest can't s3/s4 correctly if disable guest-stats-polling while balloon service running)
- bz#1183423
  (Change the copyright on all the Windows drivers to "2015" in virtio-win-prewhql build)
- bz#1184430
  (enable event index feature in Windows virtio-blk driver)
- bz#1184818
  (guest BSOD when reboot guest after enable qxl driver verifier)
- bz#1188790
  (NetKVM driver crashed on pausing in MPE test)
- bz#1190968
  ([whql][netkvm][mq]job "NDISTest 6.0 - [1 Machine] - 1c_Mini6RSSOids" last for hours and never stop w/ 4 queues)
- bz#1191836
  ([whql][netkvm][mq]job "NDISTest 6.5 - [2 Machine] - GlitchFreeDevice" failed due to "not received the expected number of packets" w/ 4 queues)
- bz#1195487
  (Windows guest performing out-of-bounds accesses on virtio device)
- bz#1195920
  (Windows 2012 R2 using virtio-scsi driver with Direct LUNs causes BSODs)
- bz#1210208
  (CVE 2015-3215 [NetKVM] Malformed packet can cause BSOD [rhel-7.2])
- bz#1212392
  (need to do extra Refresh work when initiate virtio-blk disk while boot guest with OVMF)
- bz#1217642
  (QXL XDDM is not shipped on the virtio-win ISO)
- bz#1217644
  (use hardlinks for .iso and /usr/share/virtio-win/drivers)
- bz#1217799
  (Distribute *.oem, LICENSE, COPYING in -prewhql build)
- bz#1218449
  (Ship qemuserial.cat on the iso)
- bz#1218937
  (QEMU Guest Agent VSS Provider is not started after guest tools install)
- bz#1227164
  (viostor/vioscsi is not digital signed by Redhat)
- bz#1228967
  ([virtio-win][whql][viostor]job "Flush Test" failed on all guests with build 105)

* Tue Apr 21 2015 Jeff E. Nelson <jen@redhat.com> - 1.7.4-1
- Sync with supp-rhel-7.2 virtio-win-1.7.4-1
- Resolves: bz#1207415 [rhel-6.7]
  (Change the copyright on all the Windows drivers to "2015" in virtio-win-preqhql build)
- Resolves: bz#1207413 [rhel-6.7]
  (Windows 2012 R2 using virtio-scsi-driver with Direct LUNs causes BSODs)
- Resolves: bz#1210211 [rhel-6.7]
  (CVE-2015-3215 [NetKVM] Malformed packet can cause BSOD [rhel-6.7])

* Thu Sep 11 2014 Mike Bonnet <mikeb@redhat.com> - 1.7.2-2
- Update guest-agent installers
- Resolves: rhbz#1104499

* Mon Sep  8 2014 Mike Bonnet <mikeb@redhat.com> - 1.7.2-1
- Update drivers
- Resolves: rhbz#1013443

* Wed May 28 2014 Mike Bonnet <mikeb@redhat.com> - 1.7.1-1
- Update drivers and guest-agent installers
- Resolves: rhbz#1102114

* Fri Mar 21 2014 Mike Bonnet <mikeb@redhat.com> - 1.6.8-5
- Update guest-agent installers
- Resolves: rhbz#1074613

* Wed Jan 22 2014 Mike Bonnet <mikeb@redhat.com> - 1.6.8-4
- Re-update guest-agent installers
- Related: rhbz#1034426

* Fri Jan 17 2014 Mike Bonnet <mikeb@redhat.com> - 1.6.8-3
- Update guest-agent installers
- Resolves: rhbz#1034426

* Thu Jan 16 2014 Mike Bonnet <mikeb@redhat.com> - 1.6.8-2
- Add new drivers to the .vfds and .iso
- Resolves: rhbz#1054015

* Wed Jan 15 2014 Mike Bonnet <mikeb@redhat.com> - 1.6.8-1
- Refresh the scsi driver
- Resolves: rhbz#889941

* Wed Dec  4 2013 Mike Bonnet <mikeb@redhat.com> - 1.6.7-3
- Fix the serial driver for Windows 2012
- Resolves: rhbz#1037547

* Tue Oct 29 2013 Mike Bonnet <mikeb@redhat.com> - 1.6.7-2
- Remove netkvmco.dll from the floppy images to save space
- Related: rhbz#1018649

* Tue Oct 29 2013 Mike Bonnet <mikeb@redhat.com> - 1.6.7-1
- Update to the latest version of the drivers
- Add qemu-ga installers to the .iso
- Resolves: rhbz#1018649 rhbz#1018652 rhbz#908609

* Thu Aug 15 2013 Jay Greguske <jgregusk@redhat.com> 1.6.6-1
- Resolves: 968050

* Thu Jul 11 2013 Jay Greguske <jgregusk@redhat.com> 1.6.5-6
- Resolves: 983500 (CVE-2013-2231)

* Fri Jun 28 2013 Jay Greguske <jgregusk@redhat.com> 1.6.5-5
- Resolves: 979239

* Thu Jun 27 2013 Jay Greguske <jgregusk@redhat.com> 1.6.5-4
- Resolves: 978648 978282 977686

* Wed Jun 26 2013 Jay Greguske <jgregusk@redhat.com> 1.6.5-3
- Use OS-specific cat files for each OS

* Tue Jun 25 2013 Jay Greguske <jgregusk@redhat.com> 1.6.5-2
- Use an uncorrupted amd64 cat file

* Mon Jun 24 2013 Jay Greguske <jgregusk@redhat.com> 1.6.5-1
- Resolves 976310

* Mon Apr 29 2013 Jay Greguske <jgregusk@redhat.com> 1.6.4-1
- Resolves 956228

* Wed Feb 6 2013 Jay Greguske <jgregusk@redhat.com> 1.6.3-3
- added further fixed txtsetup.oem

* Wed Feb 6 2013 Jay Greguske <jgregusk@redhat.com> 1.6.3-2
- add fixed txtsetup.oem
- added win2k8r2 netkvm drivers

* Wed Feb 6 2013 Jay Greguske <jgregusk@redhat.com> 1.6.3-1
- Reorganize the VFDs to be 32/64 bit
- Fix 1009 balloon coinstallers being resigned
- Resolves: 908163, 891640

* Tue Feb 5 2013 Jay Greguske <jgregusk@redhat.com> 1.6.2-2
- Fix 1009 coinstallers being resigned
- Resolves: 891640

* Wed Jan 30 2013 Jay Greguske <jgregusk@redhat.com> 1.6.2-1
- Split up the VFD
- Resolves: 905011

* Tue Jan 29 2013 Jay Greguske <jgregusk@redhat.com> 1.6.1-2
- Remove vioser-test.pdbs
- Resolves: 838915

* Thu Jan 24 2013 Jay Greguske <jgregusk@redhat.com> 1.6.1-1
- Added drivers from submissions 1556359, 1557005, 1557012,
  1557004, 1557008, 1555597, 1552544, 1551826, 1549074,
  1546707
- Enabled Win8/2012 platforms
- Updated txtsetup.oem for Windows 2003
- Resolves: 902977, 857832, 803633, 880569, 836915,
  838021, 714908, 750421, 760022, 768795, 782268, 790305,
  797030, 797032, 797695, 799864, 800247, 800716, 801238,
  805423, 807967, 814684, 814896, 815295, 816452, 819412,
  824814, 827000, 828275, 831570, 833659, 833671, 834174,
  834175, 834179, 834679, 836474, 837321, 837758, 838002,
  838005, 838008, 839143, 839853, 840911, 841169, 841544,
  842961, 843325, 855826, 858551, 859882, 864841, 873128,
  873960, 873971, 875155, 876033, 876061, 876397, 876504,
  877333, 878291, 879143, 879178
- add the Windows guest agent and supporting .dlls to the .iso
  Resolves: 902977

* Wed Oct 31 2012 Jay Greguske <jgregusk@redhat.com> 1.6.0-1
- Added QXL drivers from submission 1534828
- Resolves: 871679

* Fri Aug 17 2012 Jay Greguske <jgregusk@redhat.com> 1.5.4-1
- Increased VFD size to 2.88M
- Resolves: 760022

* Fri Jul 6 2012 Jay Greguske <jgregusk@redhat.com> 1.5.3-1
- Updated drivers for vio-serial
- Resolved: 833659

* Tue May 29 2012 Jay Greguske <jgregusk@redhat.com> 1.5.2-1
- Fixed Windows XP block drivers

* Tue May 16 2012 Jay Greguske <jgregusk@redhat.com> 1.5.1-1
- Updated drivers for RHEL 6.3
- Resolved: 677219, 695053, 713643, 730877, 744729, 744730,
            751952, 752743, 753723, 759361, 760022, 769495,
            770499, 771390, 799178, 799182, 799190, 799248,
            799264, 808322, 808654, 810694, 811161

* Thu Oct  6 2011 Mike Bonnet <mikeb@redhat.com> - 1.4.0-1
- Updated drivers for RHEL 6.2

* Wed Aug 10 2011 Jay Greguske <jgregusk@redhat.com> - 1.3.3-0
- Removed xp/amd64 directories and drivers since we do not
  support that platform. (rhbz#728457)

* Fri Aug  5 2011 Michael Bonnet <mikeb@redhat.com> - 1.3.2-2
- fix the directory structure of the sources zip

* Thu Aug  4 2011 Mike Bonnet <mikeb@redhat.com> - 1.3.2-1
- update viostor.cat (rhbz#727799)

* Fri Jul 29 2011 Jay Greguske <jgregusk@redhat.com> 1.3.1-1
- Added new vioserial drivers (rhbz#721355)
- prewhql build: 0.1-13

* Tue Jul 26 2011 Jay Greguske <jgregusk@redhat.com> 1.3.0-1
- Added new vioserial drivers (rhbz#720540, rhbz#702258)
- prewhql build: 0.1-12
- included 00-ms-cross-cert.patch for the sake of completeness

* Tue Apr 26 2011 Jay Greguske <jgregusk@redhat.com> 1.2.0-1
- Fix 2k8-32 drivers

* Mon Apr 25 2011 Jay Greguske <jgregusk@redhat.com> 1.2.0-0
- Added viostor, vioserial and balloon drivers for 6.1 (rhbz#699570)

* Wed Mar 30 2011 Jay Greguske <jgregusk@redhat.com> 1.1.16-4
- remove hypercall drivers included in error
- add vioserial and balloon which were excluded in error

* Thu Mar 24 2011 Jay Greguske <jgregusk@redhat.com> 1.1.16-3
- fix viostor 2k8-64 driver direct from MS this time (rhbz#681958)

* Wed Mar 23 2011 Jay Greguske <jgregusk@redhat.com> - 1.1.16-2
- Sources now a zip rather than tarball
- fix viostor 2k8-64 driver (rhbz#681958)
- Removed .git in sources zip (rhbz#671187)

* Thu Feb 10 2011 Jay Greguske <jgregusk@redhat.com> - 1.1.16-1
- Fixed drivers zip (viostor, balloon and vioserial)

* Fri Jul 2 2010 Jay Greguske <jgregusk@redhat.com> - 1.1.16-0
- RHEL 6 rebuild with new drivers

* Thu May 13 2010 Dennis Gregorovic <dgregor@redhat.com> - 1.0.0-8.1.41879
- Bump for rebuild

* Mon Jan 18 2010 Jay Greguske <jgregusk@redhat.com> - 1.0.0-8.41879
- Updated drivers from sm17 tags

* Tue Nov 17 2009 Jay Greguske <jgregusk@redhat.com> - 1.0.0-7.39539
- Packages built with the rhevm-2.1 branch
- included installer fixes

* Mon Nov 16 2009 Jay Greguske <jgregusk@redhat.com> - 1.0.0-6.37540
- license file is in .txt format
- included fix to installers so the correct block drivers are used

* Wed Nov  4 2009 Jay Greguske <jgregusk@redhat.com> - 1.0.0-5.37540
- Added new license documentation

* Tue Nov  3 2009 Jay Greguske <jgregusk@redhat.com> - 1.0.0-4.37540
- Added dual-signed x64 2008/2008r2 net drivers

* Thu Jun 18 2009 Jay Greguske <jgregusk@redhat.com> - 1.0.0-2.31351
- Fixed licensing issue in source tarball

* Wed Jun 17 2009 Mike Bonnet <mikeb@redhat.com> - 1.0.0-1.31351
- rebuild from the latest upstream sources

* Thu May  7 2009 Mike Bonnet <mikeb@redhat.com> - 1.0.0-1.28503
- Initial build
